@@ -18,15 +18,15 @@ use Sort::Key      qw/nkeysort/;
 
 =head1 NAME
 
-File::CleanupTask - Delete/Backup files on a task-based configuration
+File::CleanupTask - Delete or back up files using a task-based configuration
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 
 =head1 SYNOPSIS
@@ -71,10 +71,10 @@ The following options can be specified under a task label:
 
 =head3 path
 
-The path to the directory containing the files to be deleted or removed. Note
-that in MS Windows the backslashes of a path names should be escaped and
-apostrophese are strictly needed when specifying a path name (see example
-above).
+The path to the directory containing the files to be deleted or removed.
+
+Note that for MS Windows the backslashes in a path should be escaped and single
+quotes are strictly needed when specifying a path name (see the example above).
 
 =head3 backup_path
 
@@ -121,24 +121,32 @@ be deleted.
 If set to 0, only files within "path" can be deleted/backed up.
 If set to 1, files located at any level within "path" can be deleted.
 
+If C<prune_empty_directories> is enabled and C<recursive> is disabled, then
+only empty directories that are direct children of "path" will be cleaned up.
+
+By default, this takes the 0 value.
+
 =head3 prune_empty_directories
 
-If set to 1, empty directories will be deleted regardless their age.
+If set to 1, empty directories will be deleted, respecting the C<max_days>
+option. (In versions 0.09 and older, this would not respect the max_days option.)
+
+By default, this takes the 0 value.
 
 =head3 keep_if_linked_in
 
 A pathname to a directory that may contain symlinks. If specified, it will
 prevent deletion of files and directories within path that are symlinked in
-this directory, regardless their age.
+this directory, regardless of their age.
 
 This option will be ignored in MS Windows or in other operating systems that
 don't support symlinks.
 
 =head3 do_not_delete
 
-A regular expression that defines a pattern to look for. Any pathname matching
-this pattern will not be erased, regardless their age. The regular expression
-applies to the full pathname of the file or directory.
+A regular expression that defines a pattern to look for. Any pathnames matching
+this pattern will not be erased, regardless of their age. The regular
+expression applies to the full pathname of the file or directory.
 
 =cut
 
@@ -176,13 +184,14 @@ don't support symlinks.
 Create and configure a new File::CleanupTask object.
 
 The object must be initialised as follows:
-    
+
     my $cleanup = File::Cleanup->new({
         conf => "/path/to/tasks_file.tasks",
         taskname => 'TASK_LABEL_IN_TASKFILE',
     });
 
 =cut
+
 sub new {
     my $class  = shift;
     my $params = shift;
@@ -202,7 +211,7 @@ sub new {
 =head2 command_line_run
 
 Given the arguments specified in the command line, processes them,
-creates a new File::CleanupTask object, an then calls C<run>.
+creates a new File::CleanupTask object, and then calls C<run>.
 
 Options include I<dryrun>, I<verbose>, I<task> and I<conf>.
 
@@ -220,6 +229,7 @@ Options include I<dryrun>, I<verbose>, I<task> and I<conf>.
 =back
 
 =cut
+
 sub command_line_run {
     my $class     = shift;
     my $rh_params = {};
@@ -258,6 +268,7 @@ sub command_line_run {
 Perform the cleanup
 
 =cut
+
 sub run {
 
     my $can_symlink = eval { symlink("",""); 1 };
@@ -374,6 +385,7 @@ file is encountered a target action is performed based on the state of that file
 (file or directory, symlinked, old, empty directory...).
 
 =cut
+
 sub run_one_task {
     my $self = shift;
     my $rh_task_config = shift;
@@ -502,15 +514,16 @@ sub run_one_task {
 Accessors that will tell you if running in dryrun or verbose mode.
 
 =cut
+
 sub verbose { return $_[0]->{params}{verbose}; }
 sub dryrun  { return $_[0]->{params}{dryrun}; }
 
-=head2 _build_delete_once_empty
-
+=for _build_delete_once_empty
 Builds a delete_once_empty of pathnames, each of which should be deleted only if
 all its files are also deleted.
 
 =cut
+
 sub _build_delete_once_empty {
     my $self         = shift;
     my $rh_paths     = shift;
@@ -531,12 +544,12 @@ sub _build_delete_once_empty {
     return $rh_delete_once_empty;
 }
 
-=head2 _build_never_delete
-
+=for _build_never_delete
 Builds a never_delete list of pathnames that shouldn't be deleted at any
 condition.
 
 =cut
+
 sub _build_never_delete {
     my $self         = shift;
     my $rh_paths     = shift;
@@ -593,11 +606,11 @@ sub _build_never_delete {
     return $rh_never_delete;
 }
 
-=head2 _never_delete_add_path
-
+=for _never_delete_add_path
 Adds a path to the given never_delete list.
 
 =cut
+
 sub _never_delete_add_path {
     my $self         = shift;
     my $rh_never_delete = shift;
@@ -617,11 +630,11 @@ sub _never_delete_add_path {
     return;
 }
 
-=head2 _delete_once_empty_contains
-
+=for _delete_once_empty_contains
 Checks if the given path is contained in the delete_once_empty
 
 =cut
+
 sub _delete_once_empty_contains {
     my $self         = shift;
     my $rh_delete_once_empty = shift;
@@ -632,11 +645,11 @@ sub _delete_once_empty_contains {
     return 0;
 }
 
-=head2 _delete_once_empty_add_path
-
+=for _delete_once_empty_add_path
 Adds a path to the given delete_once_empty.
 
 =cut
+
 sub _delete_once_empty_add_path {
     my $self = shift;
     my $rh_delete_once_empty = shift;
@@ -654,11 +667,11 @@ sub _delete_once_empty_add_path {
     }
 }
 
-=head2 _never_delete_contains
-
+=for _never_delete_contains
 Checks if the given path is contained in the never_delete.
 
 =cut
+
 sub _never_delete_contains {
     my $self         = shift;
     my $rh_never_delete = shift;
@@ -668,11 +681,11 @@ sub _never_delete_contains {
     return 0;
 }
 
-=head2 _path_check
-
+=for _path_check
 Checks up the given path, and returns its absolute representation.
 
 =cut
+
 sub _path_check {
     my $self = shift;
     my $path = shift;
@@ -694,7 +707,7 @@ sub _path_check {
                       : File::Spec->canonpath($path);
 }
 
-=head2 _build_plan
+=begin _build_plan
 
 Plans the actions to be executed on the files in the target path according to:
 
@@ -704,7 +717,10 @@ Plans the actions to be executed on the files in the target path according to:
 
 All files in the never_delete list can't be deleted.
 
+=end _build_plan
+
 =cut
+
 sub _build_plan {
     my $self      = shift;
     my $rh_params = shift;
@@ -821,10 +837,11 @@ sub _build_plan {
                 }
                 else {
                     ##
-                    ## May delete if:
+                    ## May delete if all these conditions are met:
                     ## - prune_empty is on
                     ## - the directory is or will be empty (all files deleted)
                     ## - the directory is not never_deleted
+                    ## - the directory is older than max_days old if specified
                     ##
 
 
@@ -842,18 +859,29 @@ sub _build_plan {
                             = ("nothing", "'do_not_delete' matched");
                     }
                     else {
-                        ##
-                        ## Delete the directory
-                        ##
-                        my $verb = $self->_is_folder_empty($dir) ? 'is' 
-                                                                 : 'will be';
+                        my $d_time = (stat($dir))[9]; # mtime
+                        if (! defined($d_time)) {
+                            ($action, $reason) = ('nothing', "unable to stat");
+                        }
+                        elsif ($self->{keep_above_epoch} &&
+                            $d_time >= $self->{keep_above_epoch}) {
 
-                        ($action, $reason) 
-                            = ('delete', sprintf('%s empty', $verb));
+                            ($action, $reason) = ('nothing', "new directory");
 
-                        $empties{$dir} = 1;
+                        }
+                        else {
+                            ##
+                            ## Delete the directory
+                            ##
+                            my $verb = $self->_is_folder_empty($dir) ? 'is' 
+                                                                    : 'will be';
+
+                            ($action, $reason) 
+                                = ('delete', sprintf('%s empty', $verb));
+
+                            $empties{$dir} = 1;
+                        }
                     }
-
                 }
 
                 ##
@@ -908,7 +936,9 @@ sub _build_plan {
                  if ( -d $f && 
                       $prune_empty && 
                       $self->_is_folder_empty($f) &&
-                      (!$self->_never_delete_contains($rh_never_delete, $f)) ) {
+                      (!$self->_never_delete_contains($rh_never_delete, $f)) &&
+                      (! $self->{keep_above_epoch} || (stat($f))[9] <= $self->{keep_above_epoch})) {
+
 
                         $self->_plan_add_action( \@plan, 
                             { action => 'delete', 
@@ -933,7 +963,7 @@ sub _build_plan {
    );
 }
 
-=head2 _plan_add_actions
+=begin _plan_add_actions
 
 Given a path to a file and the task configuration options, augment the plan
 with actions to take on that file.
@@ -955,7 +985,10 @@ Resulting actions are decided according to one or more of the followings:
 This method works under the assumption that the specified file or directory
 exists and the user has full permissions on it.
 
+=end _plan_add_actions
+
 =cut
+
 sub _plan_add_actions {
     my $self      = shift;
     my $ra_plan   = shift;
@@ -1058,11 +1091,11 @@ sub _plan_add_actions {
     return \@actions;
 }
 
-=head2 _plan_add_action
-
+=for _plan_add_action
 Adds the given action to the plan.
 
 =cut
+
 sub _plan_add_action {
     my $self      = shift;
     my $ra_plan   = shift;
@@ -1091,11 +1124,11 @@ sub _plan_add_action {
     }
 }
 
-=head2 _is_folder_empty
-
+=for _is_folder_empty
 Returns 1 if the given folder is empty.
 
 =cut
+
 sub _is_folder_empty { 
     my $self    = shift;
     my $dirname = shift; 
@@ -1103,12 +1136,12 @@ sub _is_folder_empty {
     return scalar(grep { $_ ne "." && $_ ne ".." } readdir($dh)) == 0; 
 }
 
-=head2 _execute_plan
-
+=for _execute_plan
 Execute a plan based on the given task options. Blacklist is passed to make
 sure once again that no unwanted files or directories are deleted.
 
 =cut
+
 sub _execute_plan {
     my $self      = shift;
     my $rh_params = shift;
@@ -1226,7 +1259,7 @@ sub _ensure_path {
     return 1;
 } 
 
-=head2 _refine_plan
+=begin _refine_plan
 
 Takes into account symlinks in the current plan.
 
@@ -1254,7 +1287,10 @@ The refinement is done in the following way:
 
 Return the refined plan.
 
+=end _refine_plan
+
 =cut
+
 sub _refine_plan {
     my $self        = shift;
     my $ra_plan     = shift;
@@ -1441,8 +1477,7 @@ sub _refine_plan {
     return \@final_plan;
 }
 
-=head2
-
+=for _parent_path
 Get the parent path of a given path. This method only accesses the disk if the
 f_path is found to have no parent directory (i.e., just the relative file name
 has been specified).  In this case, we check that the current working directory
@@ -1450,6 +1485,7 @@ contains the given file. If yes, we return the current working directory as the
 parent of the specified file. If not, we return undef.
 
 =cut
+
 sub _parent_path {
     my $self   = shift;
     my $f_path = shift;
@@ -1486,7 +1522,7 @@ sub _parent_path {
 }
 
 
-=head2 _postprocess_link
+=begin _postprocess_link
 
 Given a path to a symlink and a hash reference, keep the symlink target as a
 key of the hash reference (canonical path), and the path to the symlink (non
@@ -1496,7 +1532,10 @@ the same target, the value of this hashref is an arrayref of symlinks paths.
 Returns true on success, or false if a path to something else than a symlink is
 passed to this method.
 
+=end _postprocess_link
+
 =cut
+
 sub _postprocess_link {
     my $self        = shift;
     my $rh_symlinks = shift;
@@ -1516,7 +1555,7 @@ sub _postprocess_link {
     return 0;
 }
 
-=head2 _fix_pattern
+=begin _fix_pattern
 
 Refine a pattern passed from the configuration.
 
@@ -1524,7 +1563,10 @@ Currently applyes the following transformation:
     - Remove any "/" in case the user has specified a pattern in the form of
       /pattern/.
 
+=end _fix_pattern
+
 =cut
+
 sub _fix_pattern {
     my $self    = shift;
     my $pattern = shift;
